import React from 'react';
import './App.css';
import axios from "axios";

class App extends React.Component {

  
  constructor(props) {
    super(props);

    this.state = {
      score: 0,
      username:'',
      usernameChanged:false,
      pressesToReward: 0,
      scoreboard: [],
      lastPresses: []
    };    
  }

  async componentDidMount() {
    this.getDataFromServer()
  }

  async getDataFromServer(){
    try {
      // Get data from the backend
      let res = await axios.get('/score/get')
      let data = res.data

      console.log(`Data: ${data}`);

      this.setState({
        score: data.score,
        username: data.username,
        usernameChanged: false,
        scoreboard: data.scoreboard,
        lastPresses: data.lastPresses,
        pressesToReward: data.pressesToReward
      })
      
    } catch (e) {
      console.log(`Axios request failed: ${e}`);
    }
    return
  }

  async pushButton(){
    try{
      let res = null
      // If username has changed, send it to the backend, otherwise send request without body
      if(this.state.usernameChanged){
        const usernameObject = {
          username: this.state.username
        }
        res = await axios.post('/button/push', usernameObject)
      }
      else{
        res = await axios.post('/button/push')
      }

      let data = res.data

      this.setState({
        score: data.score,
        username: data.username,
        usernameChanged: false,
        scoreboard: data.scoreboard,
        lastPresses: data.lastPresses,
        pressesToReward: data.pressesToReward
      })
      
    } catch (e) {
      console.log(`Axios request failed: ${e}`);
    }
    return
  }

  mapScoresToList(list){
    return list.map(x => <p key={x.sija}>{x.sija}. {x.name} (Pisteet: {x.score})</p>)
  }
  mapPressesToList(list){
    return list.slice(0).reverse().map(x => <p key={x.id}>Palkinto: {x.reward} (Painettu: {x.time})</p>)
  }

  

  handleClick = (props) => {
    switch(props.target.className){
      case 'button0':
        this.pushButton()
        return;
      case 'button1':
        this.pushButton()
        return;
      default:
        return;
    }
  }

  handleChange = event => {
    this.setState({
      username: event.target.value,
      usernameChanged: true,
      });
      console.log("Muutoksia tehty.")
  }
  
  render() {
    return (
      <div className="app">
          <h1 className="top">Painikepeli</h1>
          <h2 className="middle left">Tulostaulu</h2>
          <h2 className="middle right">Viimeiset painallukset</h2>
          <h2 className="middle center">Pisteet: {this.state.score}</h2>
          <h2 className="allmostDown center">Painallusta seuraavaan palkintoon: {this.state.pressesToReward}</h2>
          <div className="username">
            <h3 className="header3">
              Nimimerkki:
            </h3>

              <input type="text" value={this.state.username || ''} onChange={this.handleChange} />

          </div>
          <div className="bottom left screen">
            {this.mapScoresToList(this.state.scoreboard)}
          </div>
          <div className="bottom right screen">
            {this.mapPressesToList(this.state.lastPresses)}
          </div>
          <p className="down left">Pelaajien lukumäärä: {this.state.scoreboard.length}</p>
          <p className="down right">Viimeiset {this.state.lastPresses.length} painallusta (uusin ylimpänä)</p>
          {this.state.score > 0 ? 
          <button className="button0" onClick={this.handleClick}>Painike</button>
          :
          <button className="button1" onClick={this.handleClick}>Uusi peli</button>}
          {this.state.score === 0 ?
          <h4 className="loser">Hävisit pelin!</h4>:null}
      </div>
    )
  }
}

export default App;
